==> bsl-language-server-0.20.0-ra.1.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/StyleElementConstructors.md <==
# Конструктор элемента стиля (StyleElementConstructors)

|   Тип    |    Поддерживаются<br>языки    |     Важность     |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |               Теги                |
|:--------:|:-----------------------------:|:----------------:|:------------------------------:|:-----------------------------------:|:---------------------------------:|
| `Ошибка` |             `BSL`             | `Незначительный` |              `Да`              |                 `5`                 |    `standard`<br>`badpractice`    |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
Для изменения оформления следует использовать элементы стиля, а не задавать конкретные значения непосредственно в элементах управления. Это требуется для того, чтобы аналогичные элементы управления выглядели одинаково во всех формах, где они встречаются.

Виды элементов стиля:
* Цвет (задается значение RGB)
* Шрифт (задаются вид, размер и начертание)
* Рамка (задаются тип и ширина границ)

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

## Источники
Система стандартов 
* Источник: [Стандарт: Элементы стиля](https://its.1c.ru/db/v8std#content:667:hdoc)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:StyleElementConstructors-off
// BSLLS:StyleElementConstructors-on
```

### Параметр конфигурационного файла

```json
"StyleElementConstructors": false
```

==> bsl-language-server-0.23.1.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/StyleElementConstructors.md <==
# Конструктор элемента стиля (StyleElementConstructors)

|   Тип    |    Поддерживаются<br>языки    |     Важность     |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |               Теги                |
|:--------:|:-----------------------------:|:----------------:|:------------------------------:|:-----------------------------------:|:---------------------------------:|
| `Ошибка` |             `BSL`             | `Незначительный` |              `Да`              |                 `5`                 |    `standard`<br>`badpractice`    |

<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
Для изменения оформления следует использовать элементы стиля, а не задавать конкретные значения непосредственно в элементах управления. Это требуется для того, чтобы аналогичные элементы управления выглядели одинаково во всех формах, где они встречаются.

Виды элементов стиля:

* `Цвет` - задается значение RGB
* `Шрифт` - задаются вид, размер и начертание
* `Рамка` - задаются тип и ширина границ

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

## Источники
Система стандартов 
* Источник: [Стандарт: Элементы стиля](https://its.1c.ru/db/v8std#content:667:hdoc)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:StyleElementConstructors-off
// BSLLS:StyleElementConstructors-on
```

### Параметр конфигурационного файла

```json
"StyleElementConstructors": false
```
